#pragma once
#ifndef UNDER_CE
#include <comdef.h>
#include <locale.h>
class CCrtLocaleSwitch {
public:
	//Constructor.  Optionally switches to a new LCID.
	CCrtLocaleSwitch(LCID lcNew=0);
	//Desstructor.  Restores original locale settings.
	virtual ~CCrtLocaleSwitch(){
		restore();
	}
	//Loads a _bstr_t with a string compatible with CRT setlocale function.
	static LPCTSTR loadLocaleId(LCID lcid, _bstr_t& bstrRetBuf);
	//Set the locale for the CRT using a Windows LCID.
	static bool setLocale(LCID lcNew);
	//Restores the locale set at the time the class instantiated.
	bool restore(){
		return setlocale(LC_ALL, _strLocale) ? true : false;
	}

protected:
	_bstr_t		_strLocale;
};

/*	This class saves the current thread's LCID and CRT state, then restores
	it when it goes out of scope.
*/
class CTempLocale {
public:
	CTempLocale(LCID lcid=0) : _crt(0)
	{
		_lcOrig = GetThreadLocale();
		if( lcid != _lcOrig ){
			SetThreadLocale(lcid);
			_crt.setLocale(lcid);
		}
	}

	//Restores the LCID before instantiation
	virtual ~CTempLocale(){
		restore();
	}

	//Set the thread's locale and CRT state back to what it was
	void restore(){
		if( _lcOrig != GetThreadLocale() )
			SetThreadLocale(_lcOrig);
		_crt.restore();
	}

	//Changes the locale.  Does not affect the LCID set by restore().
	void setLocale(LCID lcid){
		if( lcid == GetThreadLocale() )
			return;

		restore();
		SetThreadLocale(lcid);
		_crt.setLocale(lcid);
	}
	

protected:
	LCID	_lcOrig;
		CCrtLocaleSwitch	_crt;
};
#endif